@@ -51,7 +51,8 @@ STORAGE_DIR = "./rdffilestore"
 SPECIAL_FILE_PREFIX = "."
 
 class FileStorageFactory(object):
-    def get_store(self, uri_base=URI_BASE, store_dir=STORAGE_DIR, prefix=SPECIAL_FILE_PREFIX, shorty_length):
+    def get_store(self, uri_base=URI_BASE, store_dir=STORAGE_DIR, prefix=SPECIAL_FILE_PREFIX,
+    shorty_length=2):
         return FileStorageClient(uri_base, store_dir, prefix, shorty_length)
 
 class FileStorageObject(object):
